@@ -13,7 +13,7 @@ use URI;
 use URI::db;
 use URI::QueryParam;
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 has dsn => sub { _url_from_file(shift->_tempfile)->dbi_dsn };
 has max_connections => 5;
@@ -230,7 +230,7 @@ following new ones.
 
   $sql->on(connection => sub {
     my ($sql, $dbh) = @_;
-    ...
+    $dbh->do('pragma journal_size_limit=1000000');
   });
 
 Emitted when a new database connection has been established.
