@@ -7,7 +7,7 @@ use Mojo::Util qw(decode slurp);
 
 use constant DEBUG => $ENV{MOJO_MIGRATIONS_DEBUG} || 0;
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 has name => 'migrations';
 has 'sqlite';
@@ -41,9 +41,10 @@ sub latest {
 
 sub migrate {
   my ($self, $target) = @_;
-  $target //= $self->latest;
 
   # Unknown version
+  my $latest = $self->latest;
+  $target //= $latest;
   my ($up, $down) = @{$self->{migrations}}{qw(up down)};
   croak "Version $target has no migration" if $target != 0 && !$up->{$target};
 
@@ -55,6 +56,10 @@ sub migrate {
   my $tx = $db->begin;
   return $self if (my $active = $self->_active($db, 1)) == $target;
 
+  # Newer version
+  croak "Active version $active is greater than the latest version $latest"
+    if $active > $latest;
+
   # Up
   my $query;
   if ($active < $target) {
