@@ -3,7 +3,7 @@ use Mojo::Base 'Mojo::EventEmitter';
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 has 'poll_interval';
 has 'sqlite';
@@ -20,7 +20,7 @@ sub notify { $_[0]->_db->notify(@_[1, 2]) and return $_[0] }
 sub unlisten {
   my ($self, $name, $cb) = @_;
   my $chan = $self->{chans}{$name};
-  @$chan = grep { $cb ne $_ } @$chan;
+  @$chan = $cb ? grep { $cb ne $_ } @$chan : ();
   $self->_db->unlisten($name) and delete $self->{chans}{$name} unless @$chan;
   return $self;
 }
@@ -151,6 +151,7 @@ Notify a channel.
 
 =head2 unlisten
 
+  $pubsub = $pubsub->unlisten('foo');
   $pubsub = $pubsub->unlisten(foo => $cb);
 
 Unsubscribe from a channel.
